@@ -83,6 +83,7 @@ class Wing(AeroSandboxObject):
          * yz: YZ-distance between the root and tip of the wing
          * y: Y-distance between the root and tip of the wing
          * z: Z-distance between the root and tip of the wing
+         * y-full: Y-distance between the centerline and the tip of the wing
         If symmetric, this is doubled to obtain the full span.
         :param type: One of the above options, as a string.
         :return: span
@@ -125,6 +126,11 @@ class Wing(AeroSandboxObject):
             span = cas.fabs(
                 tip.xyz_le[2] - root.xyz_le[2]
             )
+        elif type == "y-full":
+            tip = self.xsecs[-1]
+            span = cas.fabs(
+                tip.xyz_le[1] - 0
+            )
         else:
             raise ValueError("Bad value of 'type'!")
         if self.symmetric:
@@ -217,7 +223,7 @@ class Wing(AeroSandboxObject):
     #     return cas.vertcat(x_mac, y_mac, z_mac)
 
     def mean_twist_angle(self) -> float:
-        """
+        r"""
         Returns the mean twist angle (in degrees) of the wing, weighted by span.
         You can think of it as \int_{b}(twist)db, where b is span.
         WARNING: This function's output is only exact in the case where all of the cross sections have the same twist axis!
